<?php
/**
 * Default theme options.
 *
 * @package WEN_Associate
 */

if ( ! function_exists( 'wen_associate_get_default_theme_options' ) ) :

	/**
	 * Get default theme options.
	 *
	 * @since 1.0.0
	 */
	function wen_associate_get_default_theme_options() {

		$input = array();

		// Core.
		$input['custom_css']         = '';
		$input['search_placeholder'] = __( 'Search...', 'wen-associate-pro' );

		// Header.
		$input['show_site_title']             = true;
		$input['show_tagline']                = true;
		$input['enable_top_bar']              = false;
		$input['contact_number']              = '234-235-5678';
		$input['contact_email']               = 'demo@wenthemes.com';
		$input['social_in_header']            = false;
		$input['search_in_header']            = false;
		$input['enable_circular_icons']       = true;
		$input['header_layout']               = 'layout-1';
		$input['primary_menu_alignment']      = 'left';
		$input['disable_sticky_primary_menu'] = true;

		// Layout.
		$input['site_layout']             = 'fluid';
		$input['global_layout']           = 'right-sidebar';
		$input['archive_layout']          = 'excerpt';
		$input['archive_image']           = 'large';
		$input['archive_image_alignment'] = 'center';
		$input['single_image']            = 'large';
		$input['single_image_alignment']  = 'center';

		// Pagination.
		$input['pagination_type'] = 'default';

		// Content Meta.
		$input['meta_show_date']     = true;
		$input['meta_show_author']   = true;
		$input['meta_footer_layout'] = 'default';
		$input['meta_show_category'] = true;
		$input['meta_show_tag']      = true;
		$input['meta_show_comment']  = true;

		// Footer.
		$input['copyright_text']       = sprintf( __( 'Copyright &copy; %s. All Rights Reserved.', 'wen-associate-pro' ), '[the_year] [site_link]' );
		$input['powered_by_text']      = esc_html__( 'WEN Associate Pro by ', 'wen-associate-pro' ) . '<a target="_blank" rel="designer" href="https://wenthemes.com/">WEN Themes</a>';
		$input['reset_footer_content'] = false;
		$input['go_to_top']            = true;
		$input['go_to_top_icon']       = 'fa-chevron-circle-up';

		// Blog.
		$input['excerpt_length']       = 40;
		$input['read_more_text']       = __( 'Read More ...', 'wen-associate-pro' );
		$input['exclude_categories']   = '';

		// Author Bio.
		$input['author_bio_in_single']           = false;
		$input['author_bio_show_recent_posts']   = false;
		$input['author_bio_recent_posts_number'] = 5;

		// Breadcrumb.
		$input['breadcrumb_type']      = 'disabled';

		// Font.
		$font_keys = wen_associate_get_font_family_theme_settings_options();
		foreach ( $font_keys as $k => $v ) {
			$input[ $k ]  = $v['default'];
		}
		$input['reset_font_settings'] = false;

		// Slider.
		$input['featured_slider_status']                 = 'disabled';
		$input['featured_slider_transition_effect']      = 'fadeout';
		$input['featured_slider_transition_delay']       = 3;
		$input['featured_slider_transition_duration']    = 1;
		$input['featured_slider_caption_length']         = 20;
		$input['featured_slider_enable_caption']         = true;
		$input['featured_slider_enable_arrow']           = false;
		$input['featured_slider_arrow_design']           = 'circle';
		$input['featured_slider_enable_pager']           = true;
		$input['featured_slider_pager_design']           = 'circle';
		$input['featured_slider_enable_autoplay']        = true;
		$input['featured_slider_enable_clickable_image'] = true;
		$input['featured_slider_type']                   = 'featured-category';
		$input['featured_slider_number']                 = 3;
		$input['featured_slider_category']               = '';
		$input['featured_slider_tag']                    = '';

		// WooCommerce.
		$input['woo_page_layout']       = 'right-sidebar';
		$input['woo_sidebar_primary']   = '';
		$input['woo_sidebar_secondary'] = '';

		// Color.
		$colors = wen_associate_get_default_colors();
		if ( ! empty( $colors ) ) {
			foreach ( $colors as $key => $val ) {
				$input[ $key ] = $val;
			}
		}
		$input['reset_color_settings'] = false;

		$input = apply_filters( 'wen_associate_filter_default_theme_options', $input );

		return $input;

	}

endif;
